@@ -1,8 +1,8 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'qtluaconsole.hh'
 **
-** Created: Fri Jul 3 02:47:51 2009
-**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.1)
+** Created: Tue Jan 26 17:10:04 2010
+**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.3)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -11,7 +11,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'qtluaconsole.hh' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 61
-#error "This file was generated using the moc from 4.5.1. It"
+#error "This file was generated using the moc from 4.5.3. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -24,7 +24,7 @@ static const uint qt_meta_data_QtLua__Console[] = {
        0,       // classname
        0,    0, // classinfo
        3,   12, // methods
-       0,    0, // properties
+       4,   27, // properties
        0,    0, // enums/sets
        0,    0, // constructors
 
@@ -35,6 +35,12 @@ static const uint qt_meta_data_QtLua__Console[] = {
  // slots: signature, parameters, type, tag, flags
      116,   16,   15,   15, 0x0a,
 
+ // properties: name, type, flags
+     135,  131, 0x02095003,
+     148,  131, 0x02095003,
+     159,  131, 0x02095003,
+     179,  171, 0x0a095003,
+
        0        // eod
 };
 
@@ -42,7 +48,8 @@ static const char qt_meta_stringdata_QtLua__Console[] = {
     "QtLua::Console\0\0str\0line_validate(QString)\0"
     "prefix,list,cursor_offset\0"
     "get_completion_list(QString,QStringList&,int&)\0"
-    "print(QString)\0"
+    "print(QString)\0int\0history_size\0"
+    "text_width\0text_height\0QString\0prompt\0"
 };
 
 const QMetaObject QtLua::Console::staticMetaObject = {
@@ -77,6 +84,39 @@ int QtLua::Console::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         }
         _id -= 3;
     }
+#ifndef QT_NO_PROPERTIES
+      else if (_c == QMetaObject::ReadProperty) {
+        void *_v = _a[0];
+        switch (_id) {
+        case 0: *reinterpret_cast< int*>(_v) = get_history_size(); break;
+        case 1: *reinterpret_cast< int*>(_v) = get_text_width(); break;
+        case 2: *reinterpret_cast< int*>(_v) = get_text_height(); break;
+        case 3: *reinterpret_cast< QString*>(_v) = get_prompt(); break;
+        }
+        _id -= 4;
+    } else if (_c == QMetaObject::WriteProperty) {
+        void *_v = _a[0];
+        switch (_id) {
+        case 0: set_history_size(*reinterpret_cast< int*>(_v)); break;
+        case 1: set_text_width(*reinterpret_cast< int*>(_v)); break;
+        case 2: set_text_height(*reinterpret_cast< int*>(_v)); break;
+        case 3: set_prompt(*reinterpret_cast< QString*>(_v)); break;
+        }
+        _id -= 4;
+    } else if (_c == QMetaObject::ResetProperty) {
+        _id -= 4;
+    } else if (_c == QMetaObject::QueryPropertyDesignable) {
+        _id -= 4;
+    } else if (_c == QMetaObject::QueryPropertyScriptable) {
+        _id -= 4;
+    } else if (_c == QMetaObject::QueryPropertyStored) {
+        _id -= 4;
+    } else if (_c == QMetaObject::QueryPropertyEditable) {
+        _id -= 4;
+    } else if (_c == QMetaObject::QueryPropertyUser) {
+        _id -= 4;
+    }
+#endif // QT_NO_PROPERTIES
     return _id;
 }
 
