@@ -1,8 +1,8 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'qtluastate.hh'
 **
-** Created: Wed Nov 11 20:54:40 2009
-**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.1)
+** Created: Sun Jan 24 17:42:56 2010
+**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.3)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -11,7 +11,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'qtluastate.hh' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 61
-#error "This file was generated using the moc from 4.5.1. It"
+#error "This file was generated using the moc from 4.5.3. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -23,7 +23,7 @@ static const uint qt_meta_data_QtLua__State[] = {
        2,       // revision
        0,       // classname
        0,    0, // classinfo
-       3,   12, // methods
+       4,   12, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -34,6 +34,7 @@ static const uint qt_meta_data_QtLua__State[] = {
  // slots: signature, parameters, type, tag, flags
       45,   34,   13,   13, 0x0a,
       85,   59,   13,   13, 0x0a,
+     152,  139,  133,   13, 0x0a,
 
        0        // eod
 };
@@ -43,6 +44,7 @@ static const char qt_meta_stringdata_QtLua__State[] = {
     "statements\0exec(QString)\0"
     "prefix,list,cursor_offset\0"
     "fill_completion_list(QString,QStringList&,int&)\0"
+    "Value\0use_lua,expr\0eval_expr(bool,String)\0"
 };
 
 const QMetaObject QtLua::State::staticMetaObject = {
@@ -73,9 +75,11 @@ int QtLua::State::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         case 0: output((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 1: exec((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 2: fill_completion_list((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QStringList(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
+        case 3: { Value _r = eval_expr((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const String(*)>(_a[2])));
+            if (_a[0]) *reinterpret_cast< Value*>(_a[0]) = _r; }  break;
         default: ;
         }
-        _id -= 3;
+        _id -= 4;
     }
     return _id;
 }
